@@ -8,6 +8,7 @@ those stored in a DXF or SVG file.
 import numpy as np
 
 import copy
+import hashlib
 import collections
 
 from ..points import plane_fit
@@ -241,8 +242,8 @@ class Path(parent.Geometry):
         """
         # first MD5 the points in every entity
         target = '{}{}'.format(
-            util.md5_object(bytes().join(
-                e._bytes() for e in self.entities)),
+            hashlib.md5(bytes().join(
+                e._bytes() for e in self.entities)).hexdigest(),
             self.vertices.md5())
 
         return target
@@ -314,7 +315,8 @@ class Path(parent.Geometry):
 
         Returns
         --------
-        length: float, summed length of every entity
+        length : float
+          Summed length of every entity
         """
         length = float(sum(i.length(self.vertices)
                            for i in self.entities))
@@ -1044,15 +1046,21 @@ class Path2D(Path):
 
         Parameters
         ------------
-        pitch:      float or (2,) float, length(s) in model space of pixel edges
-        origin:     (2,) float, origin position in model space
-        resolution: (2,) int, resolution in pixel space
-        fill:       bool, if True will return closed regions as filled
-        width:      int, if not None will draw outline this wide (pixels)
+        pitch : float or (2,) float
+          Length(s) in model space of pixel edges
+        origin : (2,) float
+          Origin position in model space
+        resolution : (2,) int
+          Resolution in pixel space
+        fill : bool
+          If True will return closed regions as filled
+        width : int
+          If not None will draw outline this wide (pixels)
 
         Returns
         ------------
-        raster: PIL.Image object, mode 1
+        raster : PIL.Image object, mode 1
+          Rasterized version of closed regions.
         """
         image = raster.rasterize(self,
                                  pitch=pitch,
@@ -1069,22 +1077,22 @@ class Path2D(Path):
 
         Parameters
         -----------
-        count   : int
-                    Number of points to return
-                    If there are multiple bodies, there will
-                    be up to count * bodies points returned
-        factor  : float
-                    How many points to test per loop
-                    IE, count * factor
+        count : int
+          Number of points to return
+          If there are multiple bodies, there will
+          be up to count * bodies points returned
+        factor : float
+          How many points to test per loop
+          IE, count * factor
         max_iter : int,
-                    Maximum number of intersection loops
-                    to run, total points sampled is
-                    count * factor * max_iter
+          Maximum number of intersection loops
+          to run, total points sampled is
+          count * factor * max_iter
 
         Returns
         -----------
         hit : (n, 2) float
-               Random points inside polygon
+          Random points inside polygon
         """
 
         poly = self.polygons_full
@@ -1116,7 +1124,8 @@ class Path2D(Path):
 
         Returns
         -----------
-        path_3D: Path3D version of current path
+        path_3D : Path3D
+          3D version of current path
         """
         # if there is a stored 'to_3D' transform in metadata use it
         if transform is None and 'to_3D' in self.metadata:
@@ -1195,7 +1204,8 @@ class Path2D(Path):
 
         Returns
         ---------
-        area: float, total area of polygons minus interiors
+        area : float
+          Total area of polygons minus interiors
         """
         area = float(sum(i.area for i in self.polygons_full))
         return area
@@ -1434,7 +1444,8 @@ class Path2D(Path):
 
         Returns
         ---------
-        identifier: (5,) float, unique identifier
+        identifier : (5,) float
+          Unique identifier
         """
         if len(self.polygons_full) != 1:
             raise TypeError('Identifier only valid for single body')
@@ -1443,10 +1454,15 @@ class Path2D(Path):
     @caching.cache_decorator
     def identifier_md5(self):
         """
-        Return an MD5 of the identifier
+        Return an MD5 of the identifier.
+
+        Returns
+        ----------
+        hashed : str
+          Hashed identifier.
         """
         as_int = (self.identifier * 1e4).astype(np.int64)
-        hashed = util.md5_object(as_int.tobytes(order='C'))
+        hashed = hashlib.md5(as_int.tobytes(order='C')).hexdigest()
         return hashed
 
     @property
@@ -1454,22 +1470,25 @@ class Path2D(Path):
         """
         Returns
         ----------
-        path_valid: (n,) bool, indexes of self.paths self.polygons_closed
-                         which are valid polygons
+        path_valid : (n,) bool
+          Indexes of self.paths self.polygons_closed
+          which are valid polygons.
         """
-        valid = [i is not None for i in self.polygons_closed]
-        valid = np.array(valid, dtype=bool)
+        valid = np.array(
+            [i is not None for i in self.polygons_closed],
+            dtype=bool)
         return valid
 
     @caching.cache_decorator
     def root(self):
         """
-        Which indexes of self.paths/self.polygons_closed are root curves.
-        Also known as 'shell' or 'exterior.
+        Which indexes of self.paths/self.polygons_closed
+        are root curves, also known as 'shell' or 'exterior.
 
         Returns
         ---------
-        root: (n,) int, list of indexes
+        root : (n,) int
+          List of indexes
         """
         populate = self.enclosure_directed  # NOQA
         return self._cache['root']
@@ -1500,7 +1519,8 @@ class Path2D(Path):
 
         Returns
         ----------
-        corresponding: dict, {index of self.paths of shell : [indexes of holes]}
+        corresponding : dict
+          {index of self.paths of shell : [indexes of holes]}
         """
         pairs = [(r, self.connected_paths(r, include_self=False))
                  for r in self.root]
