@@ -3,4 +3,4 @@ from .cameras import Camera
 from .scene import Scene, split_scene
 
 # add to __all__ as per pep8
-__all__ = [Camera, Scene, split_scene]
+__all__ = ['Camera', 'Scene', 'split_scene']
