@@ -313,7 +313,7 @@ def windings_aligned(triangles, normals_compare):
         difference = diagonal_dot(
             calculated, normals_compare[valid])
 
-    aligned = np.zeros(len(triangles), dtype=np.bool)
+    aligned = np.zeros(len(triangles), dtype=bool)
     aligned[valid] = difference > 0.0
 
     return aligned
@@ -575,7 +575,7 @@ def closest_point(triangles, points):
     # store the location of the closest point
     result = np.zeros_like(points)
     # which points still need to be handled
-    remain = np.ones(len(points), dtype=np.bool)
+    remain = np.ones(len(points), dtype=bool)
 
     # if we dot product this against a (n, 3)
     # it is equivalent but faster than array.sum(axis=1)
